﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using System.Threading.Tasks;
using System.Threading;

namespace SimpleDialogDemo
{
    public partial class MyDialog : UserControl
    {
        public MyDialog()
        {
            InitializeComponent();

            gridDialog.Visibility = System.Windows.Visibility.Collapsed;

            // 把第一个实例赋值给全局静态对象
            if (_instance == null)
                _instance = this;
        }

        //用来控制异步线程中 弹出框 结果返回的时机
        private static AutoResetEvent myResetEvent = new AutoResetEvent(false);

        static MessageBoxResult messageBoxResult;

        //用一个单一实例，使得应用中的所有页面使用同一个实例
        static MyDialog _instance;
        static MyDialog Instance
        {
            get
            {
                //if (_instance == null)
                //    _instance = new MyDialog();

                return _instance;
            }
        }

        /// <summary>
        /// 显示包含指定文本、标题栏标题和响应按钮的消息框
        /// </summary>
        /// <param name="messageBoxText">要显示的消息</param>
        /// <param name="caption">消息框的标题</param>
        /// <param name="button">一个值，用于指示要显示哪个按钮或哪些按钮</param>
        /// <returns>一个值，用于指示用户对消息的响应</returns>
        public static Task<MessageBoxResult> Show(string messageBoxText, string caption, MessageBoxButton button)
        {
            return Task<MessageBoxResult>.Factory.StartNew(() =>
            {
                Instance.Dispatcher.BeginInvoke(delegate
                {

                    Instance.gridDialog.Visibility = Visibility.Visible;

                    Instance.contentContainer.Content = messageBoxText;

                    Instance.txtTitle.Text = caption;

                    if (button == MessageBoxButton.OKCancel)
                    {
                        Instance.btnCancle.Visibility = Visibility.Visible;
                    }
                    else
                    {
                        Instance.btnCancle.Visibility = Visibility.Collapsed;
                    }

                    //Instance.UpdateLayout();

                    Instance.ShowMessageBoxSB.Stop();
                    Instance.ShowMessageBoxSB.Begin();
                });


                myResetEvent.WaitOne();

                return messageBoxResult;
            });
        }

        private void btnOk_Click(object sender, RoutedEventArgs e)
        {
            txtTitle.Text = "";
            contentContainer.Content = null;

            gridDialog.Visibility = System.Windows.Visibility.Collapsed;

            messageBoxResult = MessageBoxResult.OK;

            // 使异步线程的 Show() 方法继续执行
            myResetEvent.Set();
        }

        private void btnCancle_Click(object sender, RoutedEventArgs e)
        {
            txtTitle.Text = "";
            contentContainer.Content = null;

            gridDialog.Visibility = System.Windows.Visibility.Collapsed;

            messageBoxResult = MessageBoxResult.Cancel;

            myResetEvent.Set();
        }



        // 用来控制当弹出框显示的时候，如果用户点击 Back 按键，则隐藏弹出框，
        // 在 App.xaml.cs 中的 RootFrame_Navigating 事件中调用
        public static bool DialogIsOpen
        {
            get
            {
                if (Instance != null && Instance.gridDialog.Visibility == Visibility.Visible)
                {
                    Instance.btnCancle_Click(null, null);

                    return true;
                }
                else
                {
                    return false;
                }
            }
        }
    }
}
